summaryrefslogtreecommitdiff
path: root/recordmydesktop/src/rmd_rectinsert.h
diff options
context:
space:
mode:
Diffstat (limited to 'recordmydesktop/src/rmd_rectinsert.h')
-rw-r--r--recordmydesktop/src/rmd_rectinsert.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/recordmydesktop/src/rmd_rectinsert.h b/recordmydesktop/src/rmd_rectinsert.h
index 6f93cb6..9f26f7b 100644
--- a/recordmydesktop/src/rmd_rectinsert.h
+++ b/recordmydesktop/src/rmd_rectinsert.h
@@ -36,14 +36,14 @@
* with the existing ones
* \param root Root entry of the list
*
* \param wgeom New area to be inserted
*
* \returns Number of insertions during operation
*
* \note This function is reentrant and recursive. The number
* of insertions takes this into account.
*/
-int RectInsert(RectArea **root, WGeometry *wgeom);
+int RectInsert(RectArea **root, XRectangle *xrect);
/**
* Clean up a list of areas marked for update.
© All Rights Reserved
@@ -36,14 +36,14 @@
* \param root Root entry of the list
*
-* \param wgeom New area to be inserted
+* \param xrect New area to be inserted
*
* \returns Number of insertions during operation